@@ -3,7 +3,7 @@ App::DBBrowser::GetContent::Filter::ConvertDate;
 
 use warnings;
 use strict;
-use 5.016;
+use 5.014;
 
 use DateTime::Format::Strptime;
 
@@ -204,7 +204,7 @@ sub convert_date {
                             $cf->__print_busy_string( $working );
                             if ( ! eval {
                                 for my $row ( $row_idx_begin .. $#$aoa ) {
-                                    next if ! length $aoa->[$row][$col_idx];
+                                    next if ! defined $aoa->[$row][$col_idx];
                                     my $dt = $formatter->parse_datetime( $aoa->[$row][$col_idx] );
                                     if ( ! defined $dt ) {
                                         for my $row ( 1 .. $row ) {
@@ -257,18 +257,11 @@ sub __pattern_history {
     if ( $in_out eq 'in' ) {
         my $in = [
             '%Y-%m-%d %H:%M:%S',
-            '%Y-%m-%dT%H:%M:%S',
             '%Y-%m-%d %H:%M:%S.%N%z',
             '%a %d %b %Y %I:%M:%S %P',
             '%d.%m.%Y %H:%M:%S',
             '%d/%m/%Y %H:%M:%S',
-            '%m/%d/%Y %H:%M:%S',
-            '%y = two digit year (0-99)',
-            '%b = Sep; %B = September',
-            '%I = the hour on a 12-hour clock (01-12)',
-            '%p = the equivalent of AM or PM according to the locale in use',
-            '%z = timezone (eg. +2000);  %Z timezone name (eg. EST)',
-            '%u = weekday number (1-7) with Monday is 1;  %w = weekday number (0-6) with Sunday is 0',
+            '%m/%d/%Y %H:%M:%S'
         ];
         return $in;
     }
@@ -276,7 +269,7 @@ sub __pattern_history {
         my $out = [
             '%Y-%m-%d %H:%M:%S',
             '%Y-%m-%d %H:%M:%S.%6N%z',
-            $sf->{i}{dbms} eq 'Oracle' ? '%d-%b-%y %I.%M.%S.%6N %p %Z' : '%a %d %b %Y %I:%M:%S.%6N %p %Z'
+            $sf->{i}{driver} eq 'Oracle' ? '%d-%b-%y %I.%M.%S.%6N %p %Z' : '%a %d %b %Y %I:%M:%S.%6N %p %Z'
         ];
         return $out;
     }
