@@ -92,7 +92,7 @@ sub case {
             return;
         }
         push @bu, $tmp_sql->{case_stmt};
-        my $operator= '=';
+        my $operator = '=';
         if ( $menu->[$idx] eq $end ) {
             $tmp_sql->{case_stmt} .= "\n${pad1}END";
             my $case_stmt = delete $tmp_sql->{case_stmt};
@@ -106,8 +106,7 @@ sub case {
         }
         elsif ( $menu->[$idx] eq $when ) {
             my $substmt_type = "${pad2}WHEN";
-            my $ret = $sb->__add_condition( $tmp_sql, $clause, $substmt_type, $qt_cols );
-
+            my $ret = $sb->add_condition( $tmp_sql, $clause, $substmt_type, $qt_cols ); ##
             if ( ! defined $ret ) {
                 delete $tmp_sql->{when_stmt};
                 $tmp_sql->{case_stmt} = pop @bu;
@@ -116,9 +115,9 @@ sub case {
             $tmp_sql->{case_stmt} .= "\n" . delete $tmp_sql->{when_stmt};
             $tmp_sql->{case_stmt} .= " THEN";
             push @{$r_data->{case}}, $tmp_sql->{case_stmt};
-            my $value = $ext->value( $tmp_sql, $clause, $r_data, $operator);
+            my $value = $ext->value( $tmp_sql, $clause, $r_data, $operator, { is_numeric => -1 } );
             pop @{$r_data->{case}};
-            if ( ! defined $value ) {
+            if ( ! defined $value ) { ##
                 $tmp_sql->{case_stmt} = pop @bu;
                 next SUBSTMT;
             }
@@ -127,7 +126,7 @@ sub case {
         elsif ( $menu->[$idx] eq $else ) {
             $tmp_sql->{case_stmt} .= "\n${pad2}ELSE";
             push @{$r_data->{case}}, $tmp_sql->{case_stmt};
-            my $value = $ext->value( $tmp_sql, $clause, $r_data, $operator);
+            my $value = $ext->value( $tmp_sql, $clause, $r_data, $operator, { is_numeric => -1 } );
             pop @{$r_data->{case}};
             if ( ! defined $value ) {
                 $tmp_sql->{case_stmt} = pop @bu;
